remove dead session fields
[l2tpns.git] / l2tpns.h
index 5245948..13bb1fd 100644 (file)
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.51 2005-01-07 07:17:13 bodea Exp $
+// $Id: l2tpns.h,v 1.63 2005-04-18 05:07:20 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -19,7 +19,7 @@
 
 // Limits
 #define MAXTUNNEL      500             // could be up to 65535
-#define MAXSESSION     50000           // could be up to 65535
+#define MAXSESSION     60000           // could be up to 65535
 #define MAXTBFS                6000            // Maximum token bucket filters. Might need up to 2 * session.
 
 #define RADIUS_SHIFT   5
@@ -32,6 +32,8 @@
 #define        MAXCONTROL      1000            // max length control message we ever send...
 #define        MAXETHER        (1500+18)       // max packet we try sending to tun
 #define        MAXTEL          96              // telephone number
+#define MAXUSER                128             // username
+#define MAXPASS                128             // password
 #define MAXPLUGINS     20              // maximum number of plugins to load
 #define MAXRADSERVER   10              // max radius servers
 #define        MAXROUTE        10              // max static routes per session
 #define LIBDIR         "/usr/lib/l2tpns"
 #endif
 
-#ifndef STATEDIR
-#define STATEDIR       "/var/lib/l2tpns"
-#endif
-
 #ifndef PLUGINDIR
 #define PLUGINDIR      LIBDIR          // Plugins
 #endif
 #define FLASHDIR       ETCDIR
 #endif
 
-#ifndef DATADIR
-#define DATADIR                STATEDIR
-#endif
-
 #define TUNDEVICE      "/dev/net/tun"
 #define RANDOMDEVICE   "/dev/urandom"                  // default, not as secure as /dev/random but non-blocking
-#define STATEFILE      DATADIR "/state.dump"           // State dump file
 #define CONFIGFILE     FLASHDIR "/startup-config"      // Configuration file
 #define CLIUSERS       FLASHDIR "/users"               // CLI Users file
 #define IPPOOLFILE     FLASHDIR "/ip_pool"             // Address pool configuration
@@ -150,9 +143,6 @@ struct cli_tunnel_actions {
 
 #define CLI_TUN_KILL           0x01
 
-// dump header: update number if internal format changes
-#define DUMP_MAGIC "L2TPNS#" VERSION "#"
-
 // structures
 typedef struct                 // route
 {
@@ -176,7 +166,7 @@ typedef struct
        tunnelidt tunnel;               // near end tunnel ID
        in_addr_t ip;                   // IP of session set by RADIUS response (host byte order).
        int ip_pool_index;              // index to IP pool
-       unsigned long unique_id;        // unique session id
+       uint32_t unique_id;             // unique session id
        uint16_t nr;                    // next receive
        uint16_t ns;                    // next send
        uint32_t magic;                 // ppp magic number
@@ -184,7 +174,6 @@ typedef struct
        uint32_t pin, pout;             // packet counts
        uint32_t total_cin;             // This counter is never reset while a session is open
        uint32_t total_cout;            // This counter is never reset while a session is open
-       uint32_t id;                    // session id
        uint16_t throttle_in;           // upstream throttle rate (kbps)
        uint16_t throttle_out;          // downstream throttle rate
        clockt opened;                  // when started
@@ -197,12 +186,10 @@ typedef struct
        uint16_t tbf_in;                // filter bucket for throttling in from the user.
        uint16_t tbf_out;               // filter bucket for throttling out to the user.
        uint8_t l2tp_flags;             // various bit flags from the ICCN on the l2tp tunnel.
-       uint8_t reserved_old_snoop;     // No longer used - remove at some time
        uint8_t walled_garden;          // is this session gardened?
-       uint8_t flags1;                 // additional flags (currently unused);
        char random_vector[MAXTEL];
        int random_vector_length;
-       char user[129];                 // user (needed in seesion for radius stop messages) (can we reduce this? --mo)
+       char user[MAXUSER];             // user (needed in seesion for radius stop messages)
        char called[MAXTEL];            // called number
        char calling[MAXTEL];           // calling number
        uint32_t tx_connect_speed;
@@ -213,7 +200,9 @@ typedef struct
        uint16_t sid;                   // near end session id.
        uint8_t filter_in;              // input filter index (to ip_filters[N-1]; 0 if none)
        uint8_t filter_out;             // output filter index
-       char reserved[18];              // Space to expand structure without changing HB_VERSION
+       struct in6_addr ipv6route;      // Static IPv6 route
+       uint8_t ipv6prefixlen;          // IPv6 route prefix length
+       char reserved[1];               // Space to expand structure without changing HB_VERSION
 }
 sessiont;
 
@@ -222,15 +211,22 @@ sessiont;
 #define SF_CCP_ACKED   4       // CCP negotiated
 #define SF_IPV6CP_ACKED        8       // IPv6 negotiated
 #define SF_IPV6_NACKED 16      // IPv6 rejected
+#define SF_IPV6_ROUTED 32      // advertised v6 route
 
 #define AUTHPAP                1       // allow PAP
 #define AUTHCHAP       2       // allow CHAP
 
 typedef struct
 {
+       // byte counters
        uint32_t cin;
        uint32_t cout;
-} sessioncountt;
+
+       // DoS prevention
+       clockt last_packet_out;
+       uint32_t packets_out;
+       uint32_t packets_dropped;
+} sessionlocalt;
 
 #define        SESSIONPFC      1       // PFC negotiated flags
 #define        SESSIONACFC     2       // ACFC negotiated flags
@@ -333,6 +329,7 @@ struct Tstats
     uint32_t   tun_tx_bytes;
     uint32_t   tun_rx_errors;
     uint32_t   tun_tx_errors;
+    uint32_t   tun_rx_dropped;
 
     uint32_t   tunnel_rx_packets;
     uint32_t   tunnel_tx_packets;
@@ -370,11 +367,14 @@ struct Tstats
 #ifdef STATISTICS
     uint32_t   call_processtun;
     uint32_t   call_processipout;
+    uint32_t   call_processipv6out;
     uint32_t   call_processudp;
     uint32_t   call_sessionbyip;
+    uint32_t   call_sessionbyipv6;
     uint32_t   call_sessionbyuser;
     uint32_t   call_sendarp;
     uint32_t   call_sendipcp;
+    uint32_t   call_processipv6cp;
     uint32_t   call_tunnelsend;
     uint32_t   call_sessionkill;
     uint32_t   call_sessionshutdown;
@@ -389,6 +389,7 @@ struct Tstats
     uint32_t   call_processlcp;
     uint32_t   call_processipcp;
     uint32_t   call_processipin;
+    uint32_t   call_processipv6in;
     uint32_t   call_processccp;
     uint32_t   call_sendchap;
     uint32_t   call_processrad;
@@ -456,7 +457,6 @@ typedef struct
        unsigned long   rl_rate;                        // default throttle rate
        int             num_tbfs;                       // number of throttle buckets
 
-       int             save_state;
        char            accounting_dir[128];
        in_addr_t       bind_address;
        in_addr_t       peer_address;
@@ -470,7 +470,8 @@ typedef struct
        int             next_tbf;                       // Next HTB id available to use
        int             scheduler_fifo;                 // If the system has multiple CPUs, use FIFO scheduling policy for this process.
        int             lock_pages;                     // Lock pages into memory.
-       int             icmp_rate;                      // Max number of ICMP unreachable per second to send>
+       int             icmp_rate;                      // Max number of ICMP unreachable per second to send
+       int             max_packets;                    // DoS prevention: per session limit of packets/0.1s
 
        in_addr_t       cluster_address;                // Multicast address of cluster.
                                                        // Send to this address to have everyone hear.
@@ -492,6 +493,8 @@ typedef struct
        int             cluster_hb_timeout;             // How many missed heartbeats trigger an election.
        uint64_t        cluster_table_version;          // # state changes processed by cluster
 
+       struct in6_addr ipv6_prefix;                    // Our IPv6 network pool.
+
 #ifdef BGP
 #define BGP_NUM_PEERS  2
        uint16_t as_number;
@@ -574,7 +577,9 @@ void processpap(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
 void processchap(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
 void processlcp(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
 void processipcp(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
+void processipv6cp(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
 void processipin(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
+void processipv6in(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
 void processccp(tunnelidt t, sessionidt s, uint8_t *p, uint16_t l);
 void sendchap(tunnelidt t, sessionidt s);
 uint8_t *makeppp(uint8_t *b, int size, uint8_t *p, int l, tunnelidt t, sessionidt s, uint16_t mtype);
@@ -593,10 +598,14 @@ void radiusclear(uint16_t r, sessionidt s);
 
 // l2tpns.c
 clockt backoff(uint8_t try);
+void send_ipv6_ra(tunnelidt t, sessionidt s, struct in6_addr *ip);
+void route6set(sessionidt s, struct in6_addr ip, int prefixlen, int add);
 sessionidt sessionbyip(in_addr_t ip);
+sessionidt sessionbyipv6(struct in6_addr ip);
 sessionidt sessionbyuser(char *username);
 void random_data(uint8_t *buf, int len);
-void sessionshutdown(sessionidt s, char *reason);
+void sessionkill(sessionidt s, char *reason);
+void sessionshutdown(sessionidt s, char *reason, int result, int error);
 void send_garp(in_addr_t ip);
 void tunnelsend(uint8_t *buf, uint16_t l, tunnelidt t);
 void sendipcp(tunnelidt t, sessionidt s);
@@ -636,7 +645,7 @@ void host_unreachable(in_addr_t destination, uint16_t id, in_addr_t source, char
 
 extern tunnelt *tunnel;
 extern sessiont *session;
-extern sessioncountt *sess_count;
+extern sessionlocalt *sess_local;
 extern ippoolt *ip_address_pool;
 #define sessionfree (session[0].next)